body {

    font-family: Helvetica, sans-serif;

}

.page_title {

    font: 18pt Georgia, serif;
/*    font-size: 1.5em;
    font-weight: bold; */
    color: darkred;
    border-bottom: 2px solid darkred;
}

.section_title {

    font: 14pt Georgia, serif;
    color: darkred;
    border-bottom: 2px dashed darkred;
}

.report_timestamp {

    color: darkred;
    font-weight: bold;

}

.function_src {

    text-align: left;
    background: white;
}

.resume_table {

}

.resume_header_entry {
    
    color: black;
}

.resume_number_entry {

    color: darkred;
    font-weight: bold;
    text-align: right;
}

.ranges_table {

    border-spacing: 0px;
    border-bottom: solid 2px black;
    border-top: solid 2px black;
    border-left: solid 2px black;
    border-right: solid 2px black;
}

.ranges_header_entry {

    padding: 5px;
    border-bottom: solid 1px black;
    font-size: 1em;
    font-weight: bold;
    color: darkred;
    text-align: left;
}

.ranges_entry {

}

.ranges_entry_simple {

    background: #87ff75; 

}

.ranges_entry_moderate {

    background: #fffc60;

}

.ranges_entry_high {

    background: #ff5a5d;

}

.ranges_entry_untestable {

    background: #993300

}


.function_table {

    border-spacing: 0px;
    border-bottom: solid 2px black;
    border-top: solid 2px black;
    border-left: solid 2px black;
    border-right: solid 2px black;
}

.function_table_caption {

    font-size: 1.1em;
    font-weight: bold;
    color: black;
    padding: 5px;
}

.function_table_header {
    
}


.function_table_header_entry {

    padding: 5px;
    border-bottom: solid 1px black;
    font-size: 1em;
    font-weight: bold;
    color: darkred;
    text-align: left;
}

.function_entry {


}


.function_entry_simple {

    background: #87ff75; 

}

.function_entry_moderate {

    background: #fffc60;

}

.function_entry_high {

    background: #ff5a5d;

}

.function_entry_untestable {

    background: #993300

}


.function_entry_name {

    font-size: 1em;
    text-align: left;
    font-weight: bold;
    text-valign: top;

    border-top: solid 1px black;
    padding: 3px;
}

.function_entry_cyclo {

    font-size: 1em;
    text-align: right;
    text-valign: top;

    border-top: solid 1px black;
    padding: 3px;
}

.function_entry_number {

    font-size: 1em;
    text-align: right;
    text-valign: top;

    border-top: solid 1px black;
    padding: 3px;
}

.function_entry_filename {

    font-size: 1em;
    text-align: left;
    text-valign: top;

    border-top: solid 1px black;
    padding: 3px;
}

.sidemenu {
    
    border: 1px black solid;
    padding: 5px;

}

.sidemenuheader {
 
    color: darkred;
    font-size: 1.1em;
    font-weight: bold;
    border-bottom: 1px dashed darkred;
}

.sidemenuentry {


}

.menu {

}

