/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
/* Test the Unicode character type functions.
   Copyright (C) 2007 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include "test-predicate-part1.h"

    { 0x005E, 0x005E },
    { 0x0060, 0x0060 },
    { 0x00A8, 0x00A8 },
    { 0x00AF, 0x00AF },
    { 0x00B4, 0x00B4 },
    { 0x00B7, 0x00B8 },
    { 0x02B0, 0x034E },
    { 0x0350, 0x0357 },
    { 0x035D, 0x0362 },
    { 0x0374, 0x0375 },
    { 0x037A, 0x037A },
    { 0x0384, 0x0385 },
    { 0x0483, 0x0487 },
    { 0x0559, 0x0559 },
    { 0x0591, 0x05A1 },
    { 0x05A3, 0x05BD },
    { 0x05BF, 0x05BF },
    { 0x05C1, 0x05C2 },
    { 0x05C4, 0x05C4 },
    { 0x064B, 0x0652 },
    { 0x0657, 0x0658 },
    { 0x06DF, 0x06E0 },
    { 0x06E5, 0x06E6 },
    { 0x06EA, 0x06EC },
    { 0x0730, 0x074A },
    { 0x07A6, 0x07B0 },
    { 0x07EB, 0x07F5 },
    { 0x093C, 0x093C },
    { 0x094D, 0x094D },
    { 0x0951, 0x0954 },
    { 0x0971, 0x0971 },
    { 0x09BC, 0x09BC },
    { 0x09CD, 0x09CD },
    { 0x0A3C, 0x0A3C },
    { 0x0A4D, 0x0A4D },
    { 0x0ABC, 0x0ABC },
    { 0x0ACD, 0x0ACD },
    { 0x0B3C, 0x0B3C },
    { 0x0B4D, 0x0B4D },
    { 0x0BCD, 0x0BCD },
    { 0x0C4D, 0x0C4D },
    { 0x0CBC, 0x0CBC },
    { 0x0CCD, 0x0CCD },
    { 0x0D4D, 0x0D4D },
    { 0x0DCA, 0x0DCA },
    { 0x0E47, 0x0E4C },
    { 0x0E4E, 0x0E4E },
    { 0x0EC8, 0x0ECC },
    { 0x0F18, 0x0F19 },
    { 0x0F35, 0x0F35 },
    { 0x0F37, 0x0F37 },
    { 0x0F39, 0x0F39 },
    { 0x0F3E, 0x0F3F },
    { 0x0F82, 0x0F84 },
    { 0x0F86, 0x0F87 },
    { 0x0FC6, 0x0FC6 },
    { 0x1037, 0x1037 },
    { 0x1039, 0x103A },
    { 0x1087, 0x108D },
    { 0x108F, 0x108F },
    { 0x17C9, 0x17D3 },
    { 0x17DD, 0x17DD },
    { 0x1939, 0x193B },
    { 0x1B34, 0x1B34 },
    { 0x1B44, 0x1B44 },
    { 0x1B6B, 0x1B73 },
    { 0x1BAA, 0x1BAA },
    { 0x1C36, 0x1C37 },
    { 0x1C78, 0x1C7D },
    { 0x1D2C, 0x1D6A },
    { 0x1DC4, 0x1DCF },
    { 0x1DFE, 0x1DFF },
    { 0x1FBD, 0x1FBD },
    { 0x1FBF, 0x1FC1 },
    { 0x1FCD, 0x1FCF },
    { 0x1FDD, 0x1FDF },
    { 0x1FED, 0x1FEF },
    { 0x1FFD, 0x1FFE },
    { 0x2E2F, 0x2E2F },
    { 0x302A, 0x302F },
    { 0x3099, 0x309C },
    { 0x30FC, 0x30FC },
    { 0xA66F, 0xA66F },
    { 0xA67C, 0xA67D },
    { 0xA67F, 0xA67F },
    { 0xA717, 0xA721 },
    { 0xA788, 0xA788 },
    { 0xA8C4, 0xA8C4 },
    { 0xA92B, 0xA92E },
    { 0xA953, 0xA953 },
    { 0xFB1E, 0xFB1E },
    { 0xFE20, 0xFE26 },
    { 0xFF3E, 0xFF3E },
    { 0xFF40, 0xFF40 },
    { 0xFF70, 0xFF70 },
    { 0xFF9E, 0xFF9F },
    { 0xFFE3, 0xFFE3 },
    { 0x1D167, 0x1D169 },
    { 0x1D16D, 0x1D172 },
    { 0x1D17B, 0x1D182 },
    { 0x1D185, 0x1D18B },
    { 0x1D1AA, 0x1D1AD }

#define PREDICATE(c) uc_is_property_diacritic (c)
#include "test-predicate-part2.h"
