/* Determine whether group id is in calling user's group list.

   Copyright (C) 1994, 1997, 2003, 2009-2010 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef GROUP_MEMBER_H_
# define GROUP_MEMBER_H_ 1

# include <sys/types.h>

int group_member (gid_t);

#endif /* GROUP_MEMBER_H_ */
