/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
#define PREFIX "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root"
#define EXEC_PREFIX "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root"
#define BINDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/bin"
#define SBINDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/sbin"
#define LIBEXECDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/libexec"
#define DATAROOTDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share"
#define DATADIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share"
#define SYSCONFDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/etc"
#define SHAREDSTATEDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/com"
#define LOCALSTATEDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/var"
#define INCLUDEDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/include"
#define OLDINCLUDEDIR "/usr/include"
#define DOCDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/doc/gzip"
#define INFODIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/info"
#define HTMLDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/doc/gzip"
#define DVIDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/doc/gzip"
#define PDFDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/doc/gzip"
#define PSDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/doc/gzip"
#define LIBDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/lib"
#define LOCALEDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/locale"
#define MANDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/man"
#define PKGDATADIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/share/gzip"
#define PKGINCLUDEDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/include/gzip"
#define PKGLIBDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/lib/gzip"
#define PKGLIBEXECDIR "/root/mountpoint-genprog/genprog-many-bugs/gzip-bug-2009-08-16-3fe0caeada-39a362ae9d/local-root/libexec/gzip"
